@@ -5,6 +5,8 @@ import argparse
 import configparser
 import os
 from collections import OrderedDict
+if sys.version_info >= (3, 5):
+    from typing import Dict, Set, Union
 
 
 ignore_class = '[^a-zA-Z0-9]'
@@ -56,6 +58,8 @@ def process_file(input_file, file_name, word_checkers, end_pos):
                 print(match)
     except FileNotFoundError:
         pass
+    except UnicodeDecodeError:
+        pass
     return num_matched
 
 
@@ -66,7 +70,7 @@ def get_args(args=None):
                         'files in current directory')
     parser.add_argument('--blocklist', help='Comma separated list of words '
                         'to lint in any context, with possibly special '
-                        'characters between, case insensitive'
+                        'characters between, case insensitive; '
                         'DEFAULT to master,slave,whitelist,blacklist')
     parser.add_argument('--wordlist', help='Comma separated list of words '
                         'to lint as whole words, with possibly special '
@@ -80,6 +84,9 @@ def get_args(args=None):
     parser.add_argument("--max-issue-threshold", type=int, required=False,
                         help='Cause non-zero exit status of more than this '
                         'many issues found')
+    parser.add_argument("--skip-files", type=str,
+                        help='Paths to files that should _not_ be checked by '
+                        'blocklint, even if within a checked directory')
     args = vars(parser.parse_args(args))
 
     config_paths = [
@@ -94,7 +101,7 @@ def get_args(args=None):
     config = configparser.ConfigParser()
     for path in present_config_files:
         config.read(path)
-    config_settings = {}
+    config_settings = {}  # type: Dict[str, Union[str, bool, int, Set[str]]]
     if 'blocklint' in config:
         config_settings = dict(config['blocklint'])
     for key in args:
@@ -103,7 +110,15 @@ def get_args(args=None):
                 config_settings[key] = config.getboolean('blocklint', key)
             if key in ['max_issue_threshold']:
                 config_settings[key] = config.getint('blocklint', key)
+            if key in ['skip_files']:
+                config_settings[key] = config.get('blocklint', key)
             args[key] = config_settings[key]
+    if args['skip_files'] is not None:
+        # config files have multiline args
+        skip_files = args['skip_files'].split('\n')
+        skip_files = [os.path.abspath(path) for line in skip_files
+                      for path in line.split(',')]
+        args['skip_files'] = set(skip_files)
 
     # from least to most restrictive
     wordlists = ('blocklist', 'wordlist', 'exactlist')
@@ -141,6 +156,9 @@ def get_args(args=None):
         # isabs detects pipes
         elif os.path.isfile(file) or os.path.isabs(file):
             files.append(file)
+    if args['skip_files'] is not None:
+        files = [file for file in files
+            if os.path.abspath(file) not in args['skip_files']]
 
     args['files'] = files
 
